@@ -782,6 +782,9 @@ gvc_level_bar_class_init (GvcLevelBarClass *klass)
         widget_class->size_request = gvc_level_bar_size_request;
 #endif
         widget_class->size_allocate = gvc_level_bar_size_allocate;
+#if GTK_CHECK_VERSION (3, 20, 0)
+        gtk_widget_class_set_css_name (widget_class, "gvc-level-bar");
+#endif
 
         properties[PROP_ORIENTATION] =
                 g_param_spec_enum ("orientation",
